@@ -2,19 +2,17 @@
 
 import logging
 import gobject
-import dbus.mainloop.glib
+from dbus.mainloop.glib import DBusGMainLoop
 
-import sugar_stats
-from sugar_stats.rrd import Rrd
+from sugar_stats import Rrd, Collector
 
 
 logging.basicConfig(level=logging.DEBUG)
-
-gobject.threads_init()
-dbus.mainloop.glib.DBusGMainLoop(set_as_default=True)
+DBusGMainLoop(set_as_default=True)
 
 backend = Rrd('tmp', 3, ['RRA:AVERAGE:0.5:1:360'])
-sugar_stats.start(backend)
+collector = Collector(backend)
+collector.start()
 
 mainloop = gobject.MainLoop()
 try:
@@ -22,4 +20,4 @@ try:
 except KeyboardInterrupt:
     pass
 finally:
-    sugar_stats.stop()
+    collector.stop()
