@@ -1,4 +1,4 @@
-# Copyright (C) 2012, Aleksey Lim
+# Copyright (C) 2012 Aleksey Lim
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@ from sugar_stats.sniffer import Sniffer
 class System(Sniffer):
 
     def start(self):
-        self.stats.update('system.uptime', True)
+        self.update('system.uptime', True)
 
     def trigger(self):
         self._diskfree()
@@ -29,4 +29,4 @@ class System(Sniffer):
     def _diskfree(self):
         stat = os.statvfs(os.environ['HOME'])
         df = stat.f_bfree * stat.f_frsize / 1024
-        self.stats.update('system.diskfree', df)
+        self.update('system.diskfree', df)
