@@ -3,7 +3,5 @@
 from __init__ import tests
 
 from collector import *
-from rrd import *
-from server import *
 
 tests.main()
